simsopt.geo package
===================

Submodules
----------

simsopt.geo.boozersurface module
--------------------------------

.. automodule:: simsopt.geo.boozersurface
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.config module
-------------------------

.. automodule:: simsopt.geo.config
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.curve module
------------------------

.. automodule:: simsopt.geo.curve
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.curvehelical module
-------------------------------

.. automodule:: simsopt.geo.curvehelical
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.curveobjectives module
----------------------------------

.. automodule:: simsopt.geo.curveobjectives
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.curveperturbed module
---------------------------------

.. automodule:: simsopt.geo.curveperturbed
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.curverzfourier module
---------------------------------

.. automodule:: simsopt.geo.curverzfourier
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.curveplanarfourier module
-------------------------------------

.. automodule:: simsopt.geo.curveplanarfourier
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.curvexyzfourier module
----------------------------------

.. automodule:: simsopt.geo.curvexyzfourier
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.curvexyzfouriersymmetries module
--------------------------------------------

.. automodule:: simsopt.geo.curvexyzfouriersymmetries
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.finitebuild module
------------------------------

.. automodule:: simsopt.geo.finitebuild
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.framedcurve module
------------------------------

.. automodule:: simsopt.geo.framedcurve
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.jit module
----------------------

.. automodule:: simsopt.geo.jit
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.permanent\_magnet\_grid module
------------------------------------------

.. automodule:: simsopt.geo.permanent_magnet_grid
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.plotting module
---------------------------

.. automodule:: simsopt.geo.plotting
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.qfmsurface module
-----------------------------

.. automodule:: simsopt.geo.qfmsurface
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.strain_optimization module
--------------------------------------

.. automodule:: simsopt.geo.strain_optimization
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.surface module
--------------------------

.. automodule:: simsopt.geo.surface
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.surfacegarabedian module
------------------------------------

.. automodule:: simsopt.geo.surfacegarabedian
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.surfacehenneberg module
-----------------------------------

.. automodule:: simsopt.geo.surfacehenneberg
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.surfaceobjectives module
------------------------------------

.. automodule:: simsopt.geo.surfaceobjectives
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.surfacerzfourier module
-----------------------------------

.. automodule:: simsopt.geo.surfacerzfourier
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.surfacexyzfourier module
------------------------------------

.. automodule:: simsopt.geo.surfacexyzfourier
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.geo.surfacexyztensorfourier module
------------------------------------------

.. automodule:: simsopt.geo.surfacexyztensorfourier
   :members:
   :undoc-members:
   :show-inheritance:

